@@ -47,6 +47,8 @@
 #include "gok-spy.h"
 #include "gok-data.h"
 
+static gboolean input_event_received = FALSE;
+
 static GdkFilterReturn
 gok_xkb_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
 {
@@ -64,9 +66,15 @@ gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer dat
 {
 	XEvent *xevent = gdk_xevent;
 #ifdef HAVE_XINPUT
+	
 	if (xevent->type == gok_input_types[GOK_INPUT_TYPE_MOTION])
 	{
 		XDeviceMotionEvent *motion = (XDeviceMotionEvent *) xevent;
+		if (!input_event_received && motion->deviceid != gok_input_get_current ()->device->device_id)
+		{
+			GokInput *input = gok_input_find_by_device_id (motion->deviceid, TRUE);
+			gok_input_mismatch_warn (input->info);
+		}
 		gok_main_motion_listener (motion->axes_count, motion->axis_data, 
 					  motion->device_state, (long) motion->time);
 	}
@@ -74,6 +82,11 @@ gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer dat
 		 (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_RELEASE]))
 	{
 		XDeviceButtonEvent *button = (XDeviceButtonEvent *) xevent;
+		if (!input_event_received && button->deviceid != gok_input_get_current ()->device->device_id)
+		{
+			GokInput *input = gok_input_find_by_device_id (button->deviceid, TRUE);
+			gok_input_mismatch_warn (input->info);
+		}
 		gok_main_button_listener (button->button, 
 					  (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_PRESS]) ? 1 : 0, 
 					  button->state, 
@@ -83,6 +96,9 @@ gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer dat
 	{
 		return GDK_FILTER_CONTINUE;
 	}
+	input_event_received = TRUE;
+	gok_input_close_others (gok_input_get_current ());
+
 	return GDK_FILTER_REMOVE;
 #else
 	return GDK_FILTER_CONTINUE;
@@ -122,6 +138,7 @@ on_window1_realize                     (GtkWidget       *widget,
   if (!gok_keyboard_xkb_select (GDK_WINDOW_XDISPLAY (widget->window)))
 	  g_warning ("Could not register for XKB events!");
 
+  gok_input_open_all ();
   gok_input_init (gok_input_get_current (), gok_input_extension_filter);
 
   gdk_window_add_filter (NULL,
