@@ -39,6 +39,8 @@ GokKey* gok_button_find_key (GtkWidget* pWidget);
 
 static GtkToggleButtonClass *parent_class = NULL;
 
+static gboolean corepointer_detached = FALSE;
+
 /* TODO: make image/text relationship (i.e. image on left, label on right) configurable */
 
 /**
@@ -218,7 +220,30 @@ gint gok_button_enter_notify   (GtkWidget *widget, GdkEventCrossing   *event)
 	{
 		if (!strcmp (gok_data_get_name_accessmethod (), "dwellselection")) 
 		{
-		     gok_main_warn_if_corepointer_mode (_("You appear to be using GOK in \'core pointer\' mode."), TRUE);
+		    gchar *core_message1 = _("The device you are using to operate GOK "
+					     "is also controlling the system pointer (or \'mouse pointer\').  "
+					     "Conflicts with applications\' use of the pointer may interfere "
+					     "with your ability to use applications or GOK.\n\n"
+					     "We strongly recommend configuring your input device as an "
+					     "'Extended\' input device instead; see GOK Help for more information.");
+		    gchar *core_message2 = _("The device you are using to control GOK is also controlling the system pointer.\n\n"
+					     "To avoid conflict with applications\' use of the pointer, "
+					     "GOK will now disconnect the device you are using from the "
+					     "system pointer for the duration of your GOK session.\n\n"
+					     "Alternatively, you may configure GOK to use another "
+					     "input device instead; see Help for details.");
+
+		    /* TODO: Reinstate! */
+		    if (0 && gok_input_ext_devices_exist ())
+		    {
+			if (!corepointer_detached) 
+			    corepointer_detached = gok_input_detach_corepointer ();
+			gok_main_warn (core_message2, TRUE, NULL);
+		    }
+		    else
+		    {
+			gok_main_warn (core_message1, TRUE, NULL);
+		    }		    
 		}
 		gok_scanner_on_key_enter (pKey);
 	}
