@@ -255,9 +255,21 @@ void on_button_try (GtkButton* button, gpointer user_data)
 	/* if any settings have changed then refresh the keyboard */
 	if (bDataChanged == TRUE)
 	{
+		gchar *message = g_strconcat (_("You appear to be configuring GOK to use \'core pointer\' mode."),
+					      "\n\n", 
+					      _("The device you are using to operate GOK"
+						"\nis also controlling the system pointer (or \'mouse pointer\')."
+						"\nConflicts with applications\' use of the pointer may interfere"
+						"\nwith your ability to use applications or GOK.\n"
+						"\nWe strongly recommend configuring your input device as an"
+						"\n\'Extended\' input device instead; see GOK Help for more information."),
+
+					      NULL);
 		gok_main_display_scan_reset();
-		/* and post a warning if the new settings use corepointer */
-		gok_main_warn_if_corepointer_mode (_("You appear to be configuring GOK to use \'core pointer\' mode."), FALSE);
+
+		/* and post a warning if the new settings use corepointer */		
+		gok_main_warn (message, FALSE, FALSE);
+		g_free (message);
 	}
 }
 
